--
-- constructor for a survey_response
--

create or replace package survey_response
as
    function new (
        response_id in survey_responses.response_id %TYPE default null,
        survey_id in survey_responses.survey_id%TYPE default null,
        title in survey_responses.title%TYPE default null,
        notify_on_comment_p in survey_responses.notify_on_comment_p%TYPE default 'f',
        object_type in acs_objects.object_type%TYPE default 'survey_response',
        creation_date in acs_objects.creation_date%TYPE default sysdate,
        creation_user in acs_objects.creation_user%TYPE default null,
        creation_ip in acs_objects.creation_ip%TYPE default null,
        context_id in acs_objects.context_id%TYPE default null,
	initial_response_id in survey_responses.initial_response_id%TYPE default null
    ) return acs_objects.object_id%TYPE;

    function initial_response_id (
	response_id in survey_responses.response_id%TYPE
    ) return survey_responses.response_id%TYPE;

    function initial_user_id (
	response_id in survey_responses.response_id%TYPE
    ) return acs_objects.creation_user%TYPE;

    procedure remove (
        response_id in survey_responses.response_id%TYPE
    );

    procedure del (
        response_id in survey_responses.response_id%TYPE
    );

    function boolean_answer (
        answer varchar,
	question_id survey_questions.question_id%TYPE
    ) return varchar;

end survey_response;
/
show errors


create or replace package body survey_response
as
    function new (
        response_id in survey_responses.response_id %TYPE default null,
        survey_id in survey_responses.survey_id%TYPE default null,
        title in survey_responses.title%TYPE default null,
        notify_on_comment_p in survey_responses.notify_on_comment_p%TYPE default 'f',
        object_type in acs_objects.object_type%TYPE default 'survey_response',
        creation_date in acs_objects.creation_date%TYPE default sysdate,
        creation_user in acs_objects.creation_user%TYPE default null,
        creation_ip in acs_objects.creation_ip%TYPE default null,
        context_id in acs_objects.context_id%TYPE default null,
	initial_response_id in survey_responses.initial_response_id%TYPE default null
    ) return acs_objects.object_id%TYPE
    is
        v_response_id survey_responses.response_id%TYPE;
    begin
        v_response_id := acs_object.new (
            object_id => response_id,
            object_type => object_type,
            creation_date => creation_date,
            creation_user => creation_user,
            creation_ip => creation_ip,
            context_id => context_id
        );
        insert into survey_responses (response_id, survey_id, title, notify_on_comment_p, initial_response_id)
            values
            (v_response_id, new.survey_id, new.title, new.notify_on_comment_p, new.initial_response_id);
        return v_response_id;
    end new;

    function initial_response_id (
	response_id in survey_responses.response_id%TYPE
    ) return survey_responses.response_id%TYPE
    is
        v_initial_response_id survey_responses.response_id%TYPE;
    begin
        select initial_response_id into v_initial_response_id
                  from survey_responses where
                  response_id = initial_response_id.response_id;
        if v_initial_response_id is NULL then
             v_initial_response_id := initial_response_id.response_id;
        end if;
	return v_initial_response_id;
    end initial_response_id;

    function initial_user_id (
	response_id in survey_responses.response_id%TYPE
    ) return acs_objects.creation_user%TYPE
    is
        v_user_id acs_objects.creation_user%TYPE;
    begin
	select creation_user into v_user_id
	from acs_objects
	where object_id = survey_response.initial_response_id(initial_user_id.response_id);
	return v_user_id;
    end initial_user_id;

    procedure remove (
        response_id in survey_responses.response_id%TYPE
    ) is
	v_response_row survey_responses%ROWTYPE;
    begin
	for v_response_row in (select response_id from survey_responses
		where initial_response_id=remove.response_id) loop
		survey_response.del(v_response_row.response_id);
	end loop;

	survey_response.del(remove.response_id);
    end remove;

    procedure del (
        response_id in survey_responses.response_id%TYPE
    )
    is
	v_question_response_row survey_question_responses%ROWTYPE;
    begin
	for v_question_response_row in (
		select item_id
	from survey_question_responses, cr_revisions
	where response_id=del.response_id
	and attachment_answer=revision_id)
	loop
		content_item.del(v_question_response_row.item_id);
	end loop;
	
	delete from survey_question_responses
	where response_id=del.response_id;
	delete from survey_responses
		where response_id=del.response_id;
	acs_object.del(del.response_id);
    end del;

    function boolean_answer (
        answer varchar,
	question_id survey_questions.question_id%TYPE
    ) return varchar
    is
	v_answer varchar(100);
	v_presentation_options survey_questions.presentation_options%TYPE;
	v_split_pos integer;
    begin
    
    if answer is NOT NULL then
        select presentation_options into v_presentation_options
	from survey_questions where question_id=boolean_answer.question_id;
	
	v_split_pos:= instr(v_presentation_options, '/');
	
	if answer = 't' then
	    v_answer:=substr(v_presentation_options, 1, v_split_pos -1 );
	end if;   
	if answer = 'f' then
	    v_answer:=substr(v_presentation_options, v_split_pos + 1 );
	end if;
	
    else
        v_answer := '';
    end if;
    return v_answer;
    end boolean_answer;

end survey_response;
/
show errors


